==> robosystems_client-0.1.14.tar.gz: robosystems_client-0.1.14/robosystems_client/api/subgraphs/list_subgraphs.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.http_validation_error import HTTPValidationError
from ...models.list_subgraphs_response import ListSubgraphsResponse
from ...types import UNSET, Response, Unset


def _get_kwargs(
  graph_id: str,
  *,
  authorization: Union[None, Unset, str] = UNSET,
  auth_token: Union[None, Unset, str] = UNSET,
) -> dict[str, Any]:
  headers: dict[str, Any] = {}
  if not isinstance(authorization, Unset):
    headers["authorization"] = authorization

  cookies = {}
  if auth_token is not UNSET:
    cookies["auth-token"] = auth_token

  _kwargs: dict[str, Any] = {
    "method": "get",
    "url": f"/v1/{graph_id}/subgraphs",
    "cookies": cookies,
  }

  _kwargs["headers"] = headers
  return _kwargs


def _parse_response(
  *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[HTTPValidationError, ListSubgraphsResponse]]:
  if response.status_code == 200:
    response_200 = ListSubgraphsResponse.from_dict(response.json())

    return response_200
  if response.status_code == 422:
    response_422 = HTTPValidationError.from_dict(response.json())

    return response_422
  if client.raise_on_unexpected_status:
    raise errors.UnexpectedStatus(response.status_code, response.content)
  else:
    return None


def _build_response(
  *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[HTTPValidationError, ListSubgraphsResponse]]:
  return Response(
    status_code=HTTPStatus(response.status_code),
    content=response.content,
    headers=response.headers,
    parsed=_parse_response(client=client, response=response),
  )


def sync_detailed(
  graph_id: str,
  *,
  client: AuthenticatedClient,
  authorization: Union[None, Unset, str] = UNSET,
  auth_token: Union[None, Unset, str] = UNSET,
) -> Response[Union[HTTPValidationError, ListSubgraphsResponse]]:
  """List Subgraphs

   List all subgraphs for a parent graph.

  **Requirements:**
  - Valid authentication
  - Parent graph must exist and be accessible to the user
  - User must have at least 'read' permission on the parent graph

  **Returns:**
  - List of all subgraphs for the parent graph
  - Each subgraph includes its ID, name, description, type, status, and creation date

  Args:
      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
      authorization (Union[None, Unset, str]):
      auth_token (Union[None, Unset, str]):

  Raises:
      errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
      httpx.TimeoutException: If the request takes longer than Client.timeout.

  Returns:
      Response[Union[HTTPValidationError, ListSubgraphsResponse]]
  """

  kwargs = _get_kwargs(
    graph_id=graph_id,
    authorization=authorization,
    auth_token=auth_token,
  )

  response = client.get_httpx_client().request(
    **kwargs,
  )

  return _build_response(client=client, response=response)


def sync(
  graph_id: str,
  *,
  client: AuthenticatedClient,
  authorization: Union[None, Unset, str] = UNSET,
  auth_token: Union[None, Unset, str] = UNSET,
) -> Optional[Union[HTTPValidationError, ListSubgraphsResponse]]:
  """List Subgraphs

   List all subgraphs for a parent graph.

  **Requirements:**
  - Valid authentication
  - Parent graph must exist and be accessible to the user
  - User must have at least 'read' permission on the parent graph

  **Returns:**
  - List of all subgraphs for the parent graph
  - Each subgraph includes its ID, name, description, type, status, and creation date

  Args:
      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
      authorization (Union[None, Unset, str]):
      auth_token (Union[None, Unset, str]):

  Raises:
      errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
      httpx.TimeoutException: If the request takes longer than Client.timeout.

  Returns:
      Union[HTTPValidationError, ListSubgraphsResponse]
  """

  return sync_detailed(
    graph_id=graph_id,
    client=client,
    authorization=authorization,
    auth_token=auth_token,
  ).parsed


async def asyncio_detailed(
  graph_id: str,
  *,
  client: AuthenticatedClient,
  authorization: Union[None, Unset, str] = UNSET,
  auth_token: Union[None, Unset, str] = UNSET,
) -> Response[Union[HTTPValidationError, ListSubgraphsResponse]]:
  """List Subgraphs

   List all subgraphs for a parent graph.

  **Requirements:**
  - Valid authentication
  - Parent graph must exist and be accessible to the user
  - User must have at least 'read' permission on the parent graph

  **Returns:**
  - List of all subgraphs for the parent graph
  - Each subgraph includes its ID, name, description, type, status, and creation date

  Args:
      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
      authorization (Union[None, Unset, str]):
      auth_token (Union[None, Unset, str]):

  Raises:
      errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
      httpx.TimeoutException: If the request takes longer than Client.timeout.

  Returns:
      Response[Union[HTTPValidationError, ListSubgraphsResponse]]
  """

  kwargs = _get_kwargs(
    graph_id=graph_id,
    authorization=authorization,
    auth_token=auth_token,
  )

  response = await client.get_async_httpx_client().request(**kwargs)

  return _build_response(client=client, response=response)


async def asyncio(
  graph_id: str,
  *,
  client: AuthenticatedClient,
  authorization: Union[None, Unset, str] = UNSET,
  auth_token: Union[None, Unset, str] = UNSET,
) -> Optional[Union[HTTPValidationError, ListSubgraphsResponse]]:
  """List Subgraphs

   List all subgraphs for a parent graph.

  **Requirements:**
  - Valid authentication
  - Parent graph must exist and be accessible to the user
  - User must have at least 'read' permission on the parent graph

  **Returns:**
  - List of all subgraphs for the parent graph
  - Each subgraph includes its ID, name, description, type, status, and creation date

  Args:
      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
      authorization (Union[None, Unset, str]):
      auth_token (Union[None, Unset, str]):

  Raises:
      errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
      httpx.TimeoutException: If the request takes longer than Client.timeout.

  Returns:
      Union[HTTPValidationError, ListSubgraphsResponse]
  """

  return (
    await asyncio_detailed(
      graph_id=graph_id,
      client=client,
      authorization=authorization,
      auth_token=auth_token,
    )
  ).parsed

==> robosystems_client-0.1.19.tar.gz: robosystems_client-0.1.19/robosystems_client/api/subgraphs/list_subgraphs.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.http_validation_error import HTTPValidationError
from ...models.list_subgraphs_response import ListSubgraphsResponse
from ...types import UNSET, Response, Unset


def _get_kwargs(
  graph_id: str,
  *,
  token: Union[None, Unset, str] = UNSET,
  authorization: Union[None, Unset, str] = UNSET,
) -> dict[str, Any]:
  headers: dict[str, Any] = {}
  if not isinstance(authorization, Unset):
    headers["authorization"] = authorization

  params: dict[str, Any] = {}

  json_token: Union[None, Unset, str]
  if isinstance(token, Unset):
    json_token = UNSET
  else:
    json_token = token
  params["token"] = json_token

  params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

  _kwargs: dict[str, Any] = {
    "method": "get",
    "url": f"/v1/graphs/{graph_id}/subgraphs",
    "params": params,
  }

  _kwargs["headers"] = headers
  return _kwargs


def _parse_response(
  *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[HTTPValidationError, ListSubgraphsResponse]]:
  if response.status_code == 200:
    response_200 = ListSubgraphsResponse.from_dict(response.json())

    return response_200
  if response.status_code == 422:
    response_422 = HTTPValidationError.from_dict(response.json())

    return response_422
  if client.raise_on_unexpected_status:
    raise errors.UnexpectedStatus(response.status_code, response.content)
  else:
    return None


def _build_response(
  *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[HTTPValidationError, ListSubgraphsResponse]]:
  return Response(
    status_code=HTTPStatus(response.status_code),
    content=response.content,
    headers=response.headers,
    parsed=_parse_response(client=client, response=response),
  )


def sync_detailed(
  graph_id: str,
  *,
  client: AuthenticatedClient,
  token: Union[None, Unset, str] = UNSET,
  authorization: Union[None, Unset, str] = UNSET,
) -> Response[Union[HTTPValidationError, ListSubgraphsResponse]]:
  """List Subgraphs

   List all subgraphs for a parent graph.

  **Requirements:**
  - Valid authentication
  - Parent graph must exist and be accessible to the user
  - User must have at least 'read' permission on the parent graph

  **Returns:**
  - List of all subgraphs for the parent graph
  - Each subgraph includes its ID, name, description, type, status, and creation date

  Args:
      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
      token (Union[None, Unset, str]): JWT token for SSE authentication
      authorization (Union[None, Unset, str]):

  Raises:
      errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
      httpx.TimeoutException: If the request takes longer than Client.timeout.

  Returns:
      Response[Union[HTTPValidationError, ListSubgraphsResponse]]
  """

  kwargs = _get_kwargs(
    graph_id=graph_id,
    token=token,
    authorization=authorization,
  )

  response = client.get_httpx_client().request(
    **kwargs,
  )

  return _build_response(client=client, response=response)


def sync(
  graph_id: str,
  *,
  client: AuthenticatedClient,
  token: Union[None, Unset, str] = UNSET,
  authorization: Union[None, Unset, str] = UNSET,
) -> Optional[Union[HTTPValidationError, ListSubgraphsResponse]]:
  """List Subgraphs

   List all subgraphs for a parent graph.

  **Requirements:**
  - Valid authentication
  - Parent graph must exist and be accessible to the user
  - User must have at least 'read' permission on the parent graph

  **Returns:**
  - List of all subgraphs for the parent graph
  - Each subgraph includes its ID, name, description, type, status, and creation date

  Args:
      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
      token (Union[None, Unset, str]): JWT token for SSE authentication
      authorization (Union[None, Unset, str]):

  Raises:
      errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
      httpx.TimeoutException: If the request takes longer than Client.timeout.

  Returns:
      Union[HTTPValidationError, ListSubgraphsResponse]
  """

  return sync_detailed(
    graph_id=graph_id,
    client=client,
    token=token,
    authorization=authorization,
  ).parsed


async def asyncio_detailed(
  graph_id: str,
  *,
  client: AuthenticatedClient,
  token: Union[None, Unset, str] = UNSET,
  authorization: Union[None, Unset, str] = UNSET,
) -> Response[Union[HTTPValidationError, ListSubgraphsResponse]]:
  """List Subgraphs

   List all subgraphs for a parent graph.

  **Requirements:**
  - Valid authentication
  - Parent graph must exist and be accessible to the user
  - User must have at least 'read' permission on the parent graph

  **Returns:**
  - List of all subgraphs for the parent graph
  - Each subgraph includes its ID, name, description, type, status, and creation date

  Args:
      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
      token (Union[None, Unset, str]): JWT token for SSE authentication
      authorization (Union[None, Unset, str]):

  Raises:
      errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
      httpx.TimeoutException: If the request takes longer than Client.timeout.

  Returns:
      Response[Union[HTTPValidationError, ListSubgraphsResponse]]
  """

  kwargs = _get_kwargs(
    graph_id=graph_id,
    token=token,
    authorization=authorization,
  )

  response = await client.get_async_httpx_client().request(**kwargs)

  return _build_response(client=client, response=response)


async def asyncio(
  graph_id: str,
  *,
  client: AuthenticatedClient,
  token: Union[None, Unset, str] = UNSET,
  authorization: Union[None, Unset, str] = UNSET,
) -> Optional[Union[HTTPValidationError, ListSubgraphsResponse]]:
  """List Subgraphs

   List all subgraphs for a parent graph.

  **Requirements:**
  - Valid authentication
  - Parent graph must exist and be accessible to the user
  - User must have at least 'read' permission on the parent graph

  **Returns:**
  - List of all subgraphs for the parent graph
  - Each subgraph includes its ID, name, description, type, status, and creation date

  Args:
      graph_id (str): Parent graph ID (e.g., 'kg1a2b3c4d5')
      token (Union[None, Unset, str]): JWT token for SSE authentication
      authorization (Union[None, Unset, str]):

  Raises:
      errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
      httpx.TimeoutException: If the request takes longer than Client.timeout.

  Returns:
      Union[HTTPValidationError, ListSubgraphsResponse]
  """

  return (
    await asyncio_detailed(
      graph_id=graph_id,
      client=client,
      token=token,
      authorization=authorization,
    )
  ).parsed
